#include "Curve.hpp"

#include <algorithm>

namespace
{
constexpr double gUndefinedValue(std::numeric_limits<double>::quiet_NaN());
}

CurvePoint::CurvePoint(double measureDepth, double data)
    : mMeasureDepth(measureDepth)
    , data(data)
{
}

bool Curve::isEmpty() const
{
    return mPoints.empty();
}

std::size_t Curve::getSize() const
{
    return mPoints.size();
}

void Curve::addPoint(const CurvePoint & point)
{
    mPoints.push_back(point);
}

CurvePoint & Curve::getPoint(std::size_t ind)
{
    return mPoints[ind];
}

const CurvePoint & Curve::getPoint(std::size_t ind) const
{
    return mPoints[ind];
}

double Curve::getMinTvd() const
{
    auto found(std::min_element(mPoints.cbegin(), mPoints.cend(), [](const CurvePoint & a, const CurvePoint & b)
    {
        return a.mTrueVerticalDepth < b.mTrueVerticalDepth;
    }));

    if (found == mPoints.cend())
        return gUndefinedValue;

    return found->mTrueVerticalDepth;
}

double Curve::getMaxTvd() const
{
    auto found(std::max_element(mPoints.cbegin(), mPoints.cend(), [](const CurvePoint & a, const CurvePoint & b)
    {
        return a.mTrueVerticalDepth < b.mTrueVerticalDepth;
    }));

    if (found == mPoints.cend())
        return gUndefinedValue;

    return found->mTrueVerticalDepth;
}

double Curve::getMinVs() const
{
    auto found(std::min_element(mPoints.cbegin(), mPoints.cend(), [](const CurvePoint & a, const CurvePoint & b)
    {
        return a.mAzimuthProjection < b.mAzimuthProjection;
    }));

    if (found == mPoints.cend())
        return gUndefinedValue;

    return found->mAzimuthProjection;
}

double Curve::getMaxVs() const
{
    auto found(std::max_element(mPoints.cbegin(), mPoints.cend(), [](const CurvePoint & a, const CurvePoint & b)
    {
        return a.mAzimuthProjection < b.mAzimuthProjection;
    }));

    if (found == mPoints.cend())
        return gUndefinedValue;

    return found->mAzimuthProjection;
}
