#pragma once

#include <vector>

/// Точка кривой
struct CurvePoint final
{
    CurvePoint(double measureDepth, double data);

    /// Исходные данные
    double mMeasureDepth;
    double data;

    /// Вычисленные данные
    /// mX и mY - координаты на горизонтальной плоскости
    /// mTrueVerticalDepth - глубина скважины
    /// mAzimuthProjection - проекция на вертикальную плоскость, повёрнутую на величину азимута
    double mInclination = 0.0;
    double mAzimuth = 0.0;
    double mX = 0.0;
    double mY = 0.0;
    double mTrueVerticalDepth = 0.0;
    double mAzimuthProjection = 0.0;
};

/// Траектория скважины
class Curve final
{
public:
    bool isEmpty() const;
    std::size_t getSize() const;

    void addPoint(const CurvePoint & point);
    CurvePoint & getPoint(std::size_t ind);
    const CurvePoint & getPoint(std::size_t ind) const;

    double getMinTvd() const;
    double getMaxTvd() const;

    double getMinVs() const;
    double getMaxVs() const;

private:
    std::vector<CurvePoint> mPoints;
};
