#pragma once

#include <vector>

/// Точка траектории
struct TrajectoryPoint final
{
    TrajectoryPoint(double measureDepth, double inclination, double azimuth);

    /// Исходные данные
    double mMeasureDepth;
    double mInclination;
    double mAzimuth;

    /// Вычисленные данные
    /// mX и mY - координаты на горизонтальной плоскости
    /// mTrueVerticalDepth - глубина скважины
    /// mAzimuthProjection - проекция на вертикальную плоскость, повёрнутую на величину азимута
    double mX = 0.0;
    double mY = 0.0;
    double mTrueVerticalDepth = 0.0;
    double mAzimuthProjection = 0.0;
};

/// Траектория скважины
class Well final
{
public:
    bool isEmpty() const;
    std::size_t getSize() const;

    void addPoint(const TrajectoryPoint & point);
    TrajectoryPoint & getPoint(std::size_t ind);
    const TrajectoryPoint & getPoint(std::size_t ind) const;

    double getMinTvd() const;
    double getMaxTvd() const;

    double getMinVs() const;
    double getMaxVs() const;

private:
    std::vector<TrajectoryPoint> mPoints;
};

